# coding: utf-8

"""
    Endpoints

    Endpoints API for different services in SKIL  # noqa: E501

    OpenAPI spec version: 1.2.0-rc1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import skil_client
from skil_client.models.emr_resource_details import EMRResourceDetails  # noqa: E501
from skil_client.rest import ApiException


class TestEMRResourceDetails(unittest.TestCase):
    """EMRResourceDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEMRResourceDetails(self):
        """Test EMRResourceDetails"""
        # FIXME: construct object with mandatory attributes with example values
        # model = skil_client.models.emr_resource_details.EMRResourceDetails()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
